@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 16.2 Debian package creator
-# Release 2020-03-12
+# DaVinci Resolve 16.2.3 Debian package creator
+# Release 2020-06-18
 # By Daniel Tufvesson
 #
 
@@ -62,8 +62,8 @@ make_executable() {
 }
 
 # Setup variables
-RESOLVE_VERSION=16.2
-DEB_STEPPING=3
+RESOLVE_VERSION=16.2.3
+DEB_STEPPING=1
 case $1 in
     studio)
 	RESOLVE_NAME="DaVinci Resolve Studio"
@@ -105,7 +105,8 @@ check_command xorriso
 xorriso -osirrox on -indev ${INSTALLER_ARCHIVE} -extract / ${UNPACK_DIR}
 
 # Create destination directories
-if [ -e "${UNPACK_DIR}" ] ; then
+if [ -e "${DEB_DIR}" ] ; then
+    chmod a+w -R ${DEB_DIR}
     rm -rf ${DEB_DIR}
 fi
 create_directory ${DEB_DIR}
@@ -116,6 +117,7 @@ create_directory ${RESOLVE_BASE_DIR}/easyDCP
 create_directory ${RESOLVE_BASE_DIR}/scripts
 create_directory ${RESOLVE_BASE_DIR}/.license
 create_directory ${RESOLVE_BASE_DIR}/share
+create_directory ${RESOLVE_BASE_DIR}/Fairlight
 
 # Copy objects
 copy_object ${UNPACK_DIR}/bin ${RESOLVE_BASE_DIR}
@@ -147,10 +149,7 @@ cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
 SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
 EOF
 
-# Fix missing x flag
-#chmod +x ${RESOLVE_BASE_DIR}/bin/DaVinciPanelDaemon
-
-# Install panel API library
+# Extract panel API library
 create_directory ${DEB_DIR}/usr/lib/x86_64-linux-gnu
 extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib/x86_64-linux-gnu libDaVinciPanelAPI.so
 
@@ -162,7 +161,7 @@ link_object /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/Bla
 # Create common data dir
 create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
 
-# Create desktop shortcut
+# Create desktop shortcuts
 create_directory ${DEB_DIR}/usr/share/applications/
 cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
 [Desktop Entry]
@@ -177,6 +176,19 @@ Type=Application
 StartupNotify=true
 Categories=AudioVideo
 EOF
+create_directory ${DEB_DIR}/usr/share/applications/
+cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-panel-setup.desktop <<EOF
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Exec="/opt/resolve/DaVinci Resolve Panels Setup/DaVinci Resolve Panels Setup"
+Icon=/opt/resolve/graphics/DV_Panels.png
+Name=DaVinci Resolve Panels Setup
+Terminal=false
+Type=Application
+StartupNotify=true
+Categories=AudioVideo
+EOF
 
 # Create Debian package
 create_directory ${DEB_DIR}/DEBIAN
@@ -193,14 +205,17 @@ cat > ${DEB_DIR}/DEBIAN/postinst <<EOF
 chmod -R a+rw /opt/resolve/easyDCP
 chmod -R a+rw /opt/resolve/LUT
 chmod -R a+rw /opt/resolve/.license
+chmod -R a+rw /opt/resolve/Fairlight
 chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
 test ! -e /usr/lib64 && mkdir /usr/lib64 && touch /usr/lib64.by.makeresolvedeb
 test ! -h /usr/lib64/libDaVinciPanelAPI.so && ln -s /usr/lib/x86_64-linux-gnu/libDaVinciPanelAPI.so /usr/lib64/libDaVinciPanelAPI.so
+test ! -h /usr/lib/libDaVinciPanelAPI.so && ln -s /usr/lib/x86_64-linux-gnu/libDaVinciPanelAPI.so /usr/lib/libDaVinciPanelAPI.so
 exit 0
 EOF
 make_executable ${DEB_DIR}/DEBIAN/postinst
 cat > ${DEB_DIR}/DEBIAN/postrm <<EOF
 #!/bin/sh
+test -h /usr/lib/libDaVinciPanelAPI.so && rm /usr/lib/libDaVinciPanelAPI.so
 test -h /usr/lib64/libDaVinciPanelAPI.so && rm /usr/lib64/libDaVinciPanelAPI.so
 test -e /usr/lib64.by.makeresolvedeb && rmdir /usr/lib64 && rm /usr/lib64.by.makeresolvedeb
 exit 0
@@ -214,6 +229,7 @@ if [ $? -ne 0 ] ; then
 fi
 
 # Clean up
+chmod a+w -R ${DEB_DIR}
 rm -rf ${DEB_DIR}
 chmod a+w -R ${UNPACK_DIR}
 rm -rf ${UNPACK_DIR}
